@@ -31,15 +31,13 @@
 #endif
 
 #include <glib.h>
-#include <gmodule.h>
 #include <gtk/gtk.h>
 
 #include <libxfce4util/libxfce4util.h>
 
 #include "menu.h"
 #ifdef USE_DESKTOP_MENU
-#include "desktop-menu-stub.h"
-#include "xfdesktop-common.h"
+#include "xfce-desktop-menu.h"
 #endif
 
 #ifdef USE_DESKTOP_MENU
@@ -49,7 +47,7 @@ static gboolean show_desktop_menu_icons = TRUE;
 
 #ifdef USE_DESKTOP_MENU
 static void
-_stop_menu_module() {
+_stop_menu_module(void) {
     if(desktop_menu) {
         xfce_desktop_menu_stop_autoregen(desktop_menu);
         xfce_desktop_menu_destroy(desktop_menu);
@@ -58,7 +56,7 @@ _stop_menu_module() {
 }
 
 static gboolean
-_start_menu_module()
+_start_menu_module(void)
 {
     desktop_menu = xfce_desktop_menu_new(NULL, TRUE);
     if(desktop_menu) {
@@ -190,7 +188,7 @@ menu_attach(XfceDesktop *desktop)
 }
 
 void
-menu_reload()
+menu_reload(void)
 {
 #ifdef USE_DESKTOP_MENU
     if(desktop_menu)
@@ -199,7 +197,7 @@ menu_reload()
 }
 
 void
-menu_cleanup()
+menu_cleanup(void)
 {
 #ifdef USE_DESKTOP_MENU
     _stop_menu_module();
