@@ -74,7 +74,7 @@
 #endif
 
 #include <libxfce4util/libxfce4util.h>
-#include <libxfcegui4/libxfcegui4.h>
+#include <libxfce4ui/libxfce4ui.h>
 
 #include <xfconf/xfconf.h>
 
@@ -149,9 +149,8 @@ static gboolean xfce_desktop_expose(GtkWidget *w,
                                     GdkEventExpose *evt);
 static gboolean xfce_desktop_delete_event(GtkWidget *w,
                                           GdkEventAny *evt);
-static void style_set_cb(GtkWidget *w,
-                         GtkStyle *old_style,
-                         gpointer user_data);
+static void xfce_desktop_style_set(GtkWidget *w,
+                                   GtkStyle *old_style);
 
 static void xfce_desktop_connect_backdrop_settings(XfceDesktop *desktop,
                                                    XfceBackdrop *backdrop,
@@ -540,6 +539,7 @@ xfce_desktop_class_init(XfceDesktopClass *klass)
     widget_class->expose_event = xfce_desktop_expose;
     widget_class->delete_event = xfce_desktop_delete_event;
     widget_class->popup_menu = xfce_desktop_popup_menu;
+    widget_class->style_set = xfce_desktop_style_set;
     
     signals[SIG_POPULATE_ROOT_MENU] = g_signal_new("populate-root-menu",
                                                    XFCE_TYPE_DESKTOP,
@@ -768,8 +768,6 @@ xfce_desktop_realize(GtkWidget *widget)
 
     xfce_desktop_monitors_changed(desktop->priv->gscreen, desktop);
     
-    g_signal_connect(G_OBJECT(desktop), "style-set",
-                     G_CALLBACK(style_set_cb), NULL);
     g_signal_connect(G_OBJECT(desktop->priv->gscreen), "size-changed",
             G_CALLBACK(screen_size_changed_cb), desktop);
     
@@ -792,8 +790,6 @@ xfce_desktop_unrealize(GtkWidget *widget)
     
     g_return_if_fail(XFCE_IS_DESKTOP(desktop));
     
-    g_signal_handlers_disconnect_by_func(G_OBJECT(desktop),
-                                         G_CALLBACK(style_set_cb), NULL);
     if(gtk_major_version > 2
        || (gtk_major_version == 2 && gtk_minor_version >= 13))
     {
@@ -819,6 +815,7 @@ xfce_desktop_unrealize(GtkWidget *widget)
     gdk_property_delete(groot, gdk_atom_intern("_XROOTPMAP_ID", FALSE));
     gdk_property_delete(groot, gdk_atom_intern("ESETROOT_PMAP_ID", FALSE));
     gdk_window_set_back_pixmap(groot, NULL, FALSE);
+    gdk_flush();
     
     if(desktop->priv->backdrops) {
         for(i = 0; i < desktop->priv->nbackdrops; i++) {
@@ -927,14 +924,26 @@ xfce_desktop_delete_event(GtkWidget *w,
 }
 
 static void
-style_set_cb(GtkWidget *w,
-             GtkStyle *old_style,
-             gpointer user_data)
+xfce_desktop_style_set(GtkWidget *w,
+                       GtkStyle *old_style)
 {
     XfceDesktop *desktop = XFCE_DESKTOP(w);
+#ifdef ENABLE_DESKTOP_ICONS
+    gdouble old_font_size;
+#endif
     
     gdk_window_set_back_pixmap(w->window, desktop->priv->bg_pixmap, FALSE);
     gtk_widget_queue_draw(w);
+
+#ifdef ENABLE_DESKTOP_ICONS
+    old_font_size = desktop->priv->system_font_size;
+    if(xfce_desktop_ensure_system_font_size(desktop) != old_font_size
+       && desktop->priv->icon_view && !desktop->priv->icons_font_size_set)
+    {
+        xfdesktop_icon_view_set_font_size(XFDESKTOP_ICON_VIEW(desktop->priv->icon_view),
+                                          desktop->priv->system_font_size);
+    }
+#endif
 }
 
 static void
@@ -1376,3 +1385,43 @@ xfce_desktop_popup_secondary_root_menu(XfceDesktop *desktop,
     xfce_desktop_do_menu_popup(desktop, button, activate_time,
                                signals[SIG_POPULATE_SECONDARY_ROOT_MENU]);
 }
+
+void
+xfce_desktop_refresh(XfceDesktop *desktop)
+{
+    gchar buf[256];
+    guint i, max;
+
+    g_return_if_fail(XFCE_IS_DESKTOP(desktop));
+
+    if(!GTK_WIDGET_REALIZED(desktop))
+        return;
+
+    /* reload image */
+    if(desktop->priv->xinerama_stretch)
+        max = 1;
+    else
+        max = desktop->priv->nbackdrops;
+    for(i = 0; i < max; ++i) {
+        GValue val = { 0, };
+
+        g_snprintf(buf, sizeof(buf), "%smonitor%d/image-path",
+                   desktop->priv->property_prefix, i);
+        xfconf_channel_get_property(desktop->priv->channel, buf, &val);
+
+        xfce_desktop_image_filename_changed(desktop->priv->channel, buf,
+                                            &val, desktop);
+
+        if(G_VALUE_TYPE(&val))
+            g_value_unset(&val);
+    }
+
+#ifdef ENABLE_DESKTOP_ICONS
+    /* reload icon view */
+    if(desktop->priv->icon_view) {
+        gtk_widget_destroy(desktop->priv->icon_view);
+        desktop->priv->icon_view = NULL;
+    }
+    xfce_desktop_setup_icon_view(desktop);
+#endif
+}
