@@ -24,7 +24,7 @@
 
 #include <gtk/gtk.h>
 
-#include <libxfcegui4/libxfcegui4.h>
+#include <libxfce4ui/libxfce4ui.h>
 
 #include <thunar-vfs/thunar-vfs.h>
 
@@ -36,6 +36,7 @@
 #include "xfdesktop-file-icon.h"
 #include "xfdesktop-file-utils.h"
 #include "xfdesktop-file-properties-dialog.h"
+#include "xfdesktop-common.h"
 
 #define BORDER 8
 
@@ -121,7 +122,7 @@ xfdesktop_file_properties_dialog_show(GtkWindow *parent,
 {
     GtkWidget *dlg, *table, *hbox, *lbl, *img, *spacer, *notebook, *vbox,
               *entry, *combo;
-    gint row = 0, w, h;
+    gint row = 0, dw, dh;
     PangoFontDescription *pfd;
     gchar *str = NULL, buf[64];
     const gchar *rname;
@@ -140,10 +141,11 @@ xfdesktop_file_properties_dialog_show(GtkWindow *parent,
     
     g_return_if_fail(icon);
     info = xfdesktop_file_icon_peek_info(icon);
-    g_return_if_fail(info);
+    if(!info)
+        return;
     
     pfd = pango_font_description_from_string("bold");
-    gtk_icon_size_lookup(GTK_ICON_SIZE_DIALOG, &w, &h);
+    gtk_icon_size_lookup(GTK_ICON_SIZE_DIALOG, &dw, &dh);
     mime_database = thunar_vfs_mime_database_get_default();
     
     dlg = gtk_dialog_new_with_buttons(xfdesktop_icon_peek_label(XFDESKTOP_ICON(icon)),
@@ -152,7 +154,7 @@ xfdesktop_file_properties_dialog_show(GtkWindow *parent,
                                       GTK_STOCK_CLOSE, GTK_RESPONSE_ACCEPT,
                                       NULL);
     gtk_window_set_icon(GTK_WINDOW(dlg),
-                        xfdesktop_icon_peek_pixbuf(XFDESKTOP_ICON(icon), w));
+                        xfdesktop_icon_peek_pixbuf(XFDESKTOP_ICON(icon), dw));
     g_signal_connect(GTK_DIALOG(dlg), "response",
                      G_CALLBACK(gtk_widget_destroy), NULL);
     
@@ -181,7 +183,7 @@ xfdesktop_file_properties_dialog_show(GtkWindow *parent,
                      GTK_FILL, GTK_FILL, 0, 0);
     
     img = gtk_image_new_from_pixbuf(xfdesktop_icon_peek_pixbuf(XFDESKTOP_ICON(icon),
-                                                               w));
+                                                               dw));
     gtk_widget_show(img);
     gtk_box_pack_start(GTK_BOX(hbox), img, FALSE, FALSE, 0);
     
@@ -243,7 +245,7 @@ xfdesktop_file_properties_dialog_show(GtkWindow *parent,
             display_name = g_filename_display_name(link_name);
             lbl = gtk_label_new(display_name);
             g_object_set(G_OBJECT(lbl),
-                         "ellipsize", EXO_PANGO_ELLIPSIZE_START,
+                         "ellipsize", PANGO_ELLIPSIZE_START,
                          NULL);
             g_free(display_name);
             g_free(link_name);
@@ -267,7 +269,7 @@ xfdesktop_file_properties_dialog_show(GtkWindow *parent,
             GtkCellRenderer *render;
             ThunarVfsMimeHandler *handler;
             const gchar *icon_name;
-            gint w, h;
+            gint mw, mh;
             GdkPixbuf *pix;
             
             lbl = gtk_label_new(_("Open With:"));
@@ -282,7 +284,7 @@ xfdesktop_file_properties_dialog_show(GtkWindow *parent,
             gtk_table_attach(GTK_TABLE(table), hbox, 1, 2, row, row + 1,
                              GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
             
-            gtk_icon_size_lookup(GTK_ICON_SIZE_MENU, &w, &h);
+            gtk_icon_size_lookup(GTK_ICON_SIZE_MENU, &mw, &mh);
             
             ls = gtk_list_store_new(OPENWITH_N_COLS, GDK_TYPE_PIXBUF,
                                     G_TYPE_STRING, G_TYPE_POINTER);
@@ -294,8 +296,11 @@ xfdesktop_file_properties_dialog_show(GtkWindow *parent,
                 
                 icon_name = thunar_vfs_mime_handler_lookup_icon_name(handler,
                                                                      gtk_icon_theme_get_default());
-                if(icon_name)
-                    pix = xfce_themed_icon_load(icon_name, w);
+                if(icon_name) {
+                    GtkIconTheme *itheme = gtk_icon_theme_get_default();
+                    pix = gtk_icon_theme_load_icon(itheme, icon_name, mw,
+                                                   ITHEME_FLAGS, NULL);
+                }
                 
                 gtk_list_store_set(ls, &itr,
                                    OPENWITH_COL_PIX, pix,
@@ -555,7 +560,7 @@ xfdesktop_file_properties_dialog_show(GtkWindow *parent,
     
 #ifdef HAVE_THUNARX
     if(thunarx_properties_providers) {
-        GList *l, *pages, *p, *files = g_list_append(NULL, icon);
+        GList *pages, *p, *files = g_list_append(NULL, icon);
         ThunarxPropertyPageProvider *provider;
         ThunarxPropertyPage *page;
         GtkWidget *label_widget;
