@@ -28,7 +28,7 @@
 
 #include <gtk/gtk.h>
 
-#include <libxfcegui4/libxfcegui4.h>
+#include <libxfce4ui/libxfce4ui.h>
 
 #include <exo/exo.h>
 
@@ -42,6 +42,7 @@
 
 #include "xfdesktop-dbus-bindings-filemanager.h"
 #include "xfdesktop-file-icon.h"
+#include "xfdesktop-common.h"
 #include "xfdesktop-file-utils.h"
 
 ThunarVfsInteractiveJobResponse
@@ -54,7 +55,7 @@ xfdesktop_file_utils_interactive_job_ask(GtkWindow *parent,
     
     dlg = xfce_message_dialog_new(parent, _("Question"),
                                   GTK_STOCK_DIALOG_QUESTION, NULL, message,
-                                  NULL);
+                                  NULL, NULL);
     
     if(choices & THUNAR_VFS_INTERACTIVE_JOB_RESPONSE_CANCEL) {
         btn = gtk_button_new_from_stock(GTK_STOCK_CANCEL);
@@ -222,26 +223,33 @@ xfdesktop_file_utils_get_file_icon(const gchar *custom_icon_name,
                                    const GdkPixbuf *emblem,
                                    guint opacity)
 {
+    GtkIconTheme *itheme = gtk_icon_theme_get_default();
     GdkPixbuf *pix_theme = NULL, *pix = NULL;
     const gchar *icon_name;
     
-    if(custom_icon_name)
-        pix_theme = xfce_themed_icon_load(custom_icon_name, size);
-    
-    if(!pix_theme && info && info->mime_info) {
-        icon_name = thunar_vfs_mime_info_lookup_icon_name(info->mime_info,
-                                                          gtk_icon_theme_get_default());
-        DBG("got mime info icon name: %s", icon_name);
-        if(icon_name)
-            pix_theme = xfce_themed_icon_load(icon_name, size);
+    if(custom_icon_name) {
+        pix_theme = gtk_icon_theme_load_icon(itheme, custom_icon_name, size,
+                                             ITHEME_FLAGS, NULL);
     }
     
     if(!pix_theme && info) {
         icon_name = thunar_vfs_info_get_custom_icon(info);
-        if(icon_name)
-            pix_theme = xfce_themed_icon_load(icon_name, size);
+        if(icon_name) {
+            pix_theme = gtk_icon_theme_load_icon(itheme, icon_name, size,
+                                                 ITHEME_FLAGS, NULL);
+        }
     }
-            
+
+    if(!pix_theme && info && info->mime_info) {
+        icon_name = thunar_vfs_mime_info_lookup_icon_name(info->mime_info,
+                                                          gtk_icon_theme_get_default());
+        DBG("got mime info icon name: %s", icon_name);
+        if(icon_name) {
+            pix_theme = gtk_icon_theme_load_icon(itheme, icon_name, size,
+                                                 ITHEME_FLAGS, NULL);
+        }
+    }
+
     if(G_LIKELY(pix_theme)) {
         /* we can't edit thsese icons */
         pix = gdk_pixbuf_copy(pix_theme);
@@ -254,7 +262,10 @@ xfdesktop_file_utils_get_file_icon(const gchar *custom_icon_name,
         pix = xfdesktop_file_utils_get_fallback_icon(size);
     
     /* sanity check */
-    g_return_val_if_fail(G_LIKELY(pix), NULL);
+    if(G_UNLIKELY(!pix)) {
+        g_warning("Unable to find fallback icon");
+        return NULL;
+    }
     
     if(emblem) {
         gint emblem_pix_size = gdk_pixbuf_get_width(emblem);
@@ -335,13 +346,12 @@ xfdesktop_file_utils_launch_fallback(const ThunarVfsInfo *info,
         display_name = gdk_screen_make_display_name(screen);
         uri = thunar_vfs_path_dup_uri(info->path);
         
-        commandline = g_strconcat("env DISPLAY=\"", display_name,
-                                  "\" \"", file_manager_app, "\" \"",
+        commandline = g_strconcat("\"", file_manager_app, "\" \"",
                                   uri, "\"", NULL);
         
         DBG("executing:\n%s\n", commandline);
         
-        ret = xfce_exec(commandline, FALSE, TRUE, NULL);
+        ret = xfce_spawn_command_line_on_screen(screen, commandline, FALSE, TRUE, NULL);
         
         g_free(commandline);
         g_free(file_manager_app);
@@ -377,7 +387,7 @@ xfdesktop_file_utils_display_folder_cb(DBusGProxy *proxy,
 {
     XfdesktopDisplayFolderData *dfdata = user_data;
     
-    g_return_if_fail(user_data);
+    g_return_if_fail(dfdata);
     
     xfdesktop_file_utils_set_window_cursor(dfdata->parent, GDK_LEFT_PTR);
     
@@ -433,7 +443,7 @@ static DBusGProxy *dbus_trash_proxy = NULL;
 static DBusGProxy *dbus_filemanager_proxy = NULL;
 
 gboolean
-xfdesktop_file_utils_dbus_init()
+xfdesktop_file_utils_dbus_init(void)
 {
     gboolean ret = TRUE;
     
@@ -470,19 +480,19 @@ xfdesktop_file_utils_dbus_init()
 }
 
 DBusGProxy *
-xfdesktop_file_utils_peek_trash_proxy()
+xfdesktop_file_utils_peek_trash_proxy(void)
 {
     return dbus_trash_proxy;
 }
 
 DBusGProxy *
-xfdesktop_file_utils_peek_filemanager_proxy()
+xfdesktop_file_utils_peek_filemanager_proxy(void)
 {
     return dbus_filemanager_proxy;
 }
 
 void
-xfdesktop_file_utils_dbus_cleanup()
+xfdesktop_file_utils_dbus_cleanup(void)
 {
     if(dbus_ref_cnt == 0 || --dbus_ref_cnt > 0)
         return;
@@ -525,9 +535,8 @@ xfdesktop_thunarx_file_info_get_uri(ThunarxFileInfo *file_info)
     if(!info)
         return NULL;
         
-    g_return_val_if_fail(thunar_vfs_path_to_uri(info->path, buf, PATH_MAX,
-                                                NULL) > 0,
-                         NULL);
+    if(thunar_vfs_path_to_uri(info->path, buf, PATH_MAX, NULL) <= 0)
+        return NULL;
     
     return g_strdup(buf);
 }
@@ -548,9 +557,8 @@ xfdesktop_thunarx_file_info_get_parent_uri(ThunarxFileInfo *file_info)
     if(G_UNLIKELY(!parent))
         return NULL;
     
-    g_return_val_if_fail(thunar_vfs_path_to_uri(parent, buf, PATH_MAX,
-                                                NULL) > 0,
-                         NULL);
+    if(thunar_vfs_path_to_uri(parent, buf, PATH_MAX, NULL) <= 0)
+        return NULL;
     
     return g_strdup(buf);
 }
