@@ -1,7 +1,7 @@
 /*
  *  xfdesktop - xfce4's desktop manager
  *
- *  Copyright (c) 2006 Brian Tarricone, <brian@tarricone.org>
+ *  Copyright (c) 2006 Brian Tarricone, <bjt23@cornell.edu>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,8 +14,8 @@
  *  GNU Library General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software Foundation,
- *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 #ifndef __XFDESKTOP_SPECIAL_FILE_ICON_H__
@@ -23,12 +23,32 @@
 
 #include <glib-object.h>
 
+#include <thunar-vfs/thunar-vfs.h>
+
 #include "xfdesktop-file-icon.h"
 
 G_BEGIN_DECLS
 
-G_DECLARE_FINAL_TYPE(XfdesktopSpecialFileIcon, xfdesktop_special_file_icon, XFDESKTOP, SPECIAL_FILE_ICON, XfdesktopFileIcon)
-#define XFDESKTOP_TYPE_SPECIAL_FILE_ICON (xfdesktop_special_file_icon_get_type())
+#define XFDESKTOP_TYPE_SPECIAL_FILE_ICON     (xfdesktop_special_file_icon_get_type())
+#define XFDESKTOP_SPECIAL_FILE_ICON(obj)     (G_TYPE_CHECK_INSTANCE_CAST((obj), XFDESKTOP_TYPE_SPECIAL_FILE_ICON, XfdesktopSpecialFileIcon))
+#define XFDESKTOP_IS_SPECIAL_FILE_ICON(obj)  (G_TYPE_CHECK_INSTANCE_TYPE((obj), XFDESKTOP_TYPE_SPECIAL_FILE_ICON))
+
+typedef struct _XfdesktopSpecialFileIcon         XfdesktopSpecialFileIcon;
+typedef struct _XfdesktopSpecialFileIconClass    XfdesktopSpecialFileIconClass;
+typedef struct _XfdesktopSpecialFileIconPrivate  XfdesktopSpecialFileIconPrivate;
+
+struct _XfdesktopSpecialFileIcon
+{
+    XfdesktopFileIcon parent;
+    
+    /*< private >*/
+    XfdesktopSpecialFileIconPrivate *priv;
+};
+
+struct _XfdesktopSpecialFileIconClass
+{
+    XfdesktopFileIconClass parent;
+};
 
 typedef enum
 {
@@ -37,7 +57,7 @@ typedef enum
     XFDESKTOP_SPECIAL_FILE_ICON_TRASH,
 } XfdesktopSpecialFileIconType;
 
-GFile *xfdesktop_special_file_icon_file_for_type(XfdesktopSpecialFileIconType type) G_GNUC_WARN_UNUSED_RESULT;
+GType xfdesktop_special_file_icon_get_type(void) G_GNUC_CONST;
 
 XfdesktopSpecialFileIcon *xfdesktop_special_file_icon_new(XfdesktopSpecialFileIconType type,
                                                           GdkScreen *screen);
