@@ -43,7 +43,7 @@
 #define PATH_MAX 4096
 #endif
 
-#include <libxfcegui4/libxfcegui4.h>
+#include <libxfce4ui/libxfce4ui.h>
 
 #ifdef HAVE_THUNARX
 #include <thunarx/thunarx.h>
@@ -310,7 +310,10 @@ xfdesktop_volume_icon_drag_job_error(ThunarVfsJob *job,
                                                                         "--xfdesktop-file-icon-action"));
     const ThunarVfsInfo *src_info = xfdesktop_file_icon_peek_info(src_file_icon);
     
-    g_return_if_fail(volume_icon && src_file_icon);
+    g_return_if_fail(volume_icon);
+    
+    if(!src_file_icon)
+        return;
     
     xfdesktop_file_utils_handle_fileop_error(NULL, src_info,
                                              volume_icon->priv->info,
@@ -363,8 +366,7 @@ xfdesktop_volume_icon_do_drop_dest(XfdesktopIcon *icon,
     
     DBG("entering");
     
-    g_return_val_if_fail(volume_icon && src_file_icon,
-                         FALSE);
+    g_return_val_if_fail(volume_icon && src_file_icon, FALSE);
     g_return_val_if_fail(xfdesktop_volume_icon_get_allowed_drop_actions(icon),
                          FALSE);
     
@@ -376,11 +378,13 @@ xfdesktop_volume_icon_do_drop_dest(XfdesktopIcon *icon,
         return FALSE;
     
     name = thunar_vfs_path_get_name(src_info->path);
-    g_return_val_if_fail(name, FALSE);
+    if(!name)
+        return FALSE;
         
     dest_path = thunar_vfs_path_relative(volume_icon->priv->info->path,
                                          name);
-    g_return_val_if_fail(dest_path, FALSE);
+    if(!dest_path)
+        return FALSE;
     
     switch(action) {
         case GDK_ACTION_MOVE:
@@ -554,6 +558,7 @@ xfdesktop_volume_icon_populate_context_menu(XfdesktopIcon *icon,
     XfdesktopVolumeIcon *volume_icon = XFDESKTOP_VOLUME_ICON(icon);
     ThunarVfsVolume *volume = volume_icon->priv->volume;
     GtkWidget *mi, *img;
+    gboolean mounted, ejectable;
     
     img = gtk_image_new_from_stock(GTK_STOCK_OPEN, GTK_ICON_SIZE_MENU);
     gtk_widget_show(img);
@@ -568,43 +573,42 @@ xfdesktop_volume_icon_populate_context_menu(XfdesktopIcon *icon,
     gtk_widget_show(mi);
     gtk_menu_shell_append(GTK_MENU_SHELL(menu), mi);
     
-    mi = gtk_image_menu_item_new_with_mnemonic(_("_Mount Volume"));
-    gtk_widget_show(mi);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu), mi);
-    if(thunar_vfs_volume_is_mounted(volume))
-        gtk_widget_set_sensitive(mi, FALSE);
-    else {
+    mounted = thunar_vfs_volume_is_mounted(volume);
+    ejectable = thunar_vfs_volume_is_ejectable(volume);
+
+    if(!mounted || (mounted && !ejectable)) {
+        if(mounted) {
+            img = gtk_image_new_from_stock(GTK_STOCK_DISCONNECT, GTK_ICON_SIZE_MENU);
+            mi = gtk_image_menu_item_new_with_mnemonic(_("_Unmount Volume"));
+        } else {
+            img = gtk_image_new_from_stock(GTK_STOCK_CONNECT, GTK_ICON_SIZE_MENU);
+            mi = gtk_image_menu_item_new_with_mnemonic(_("_Mount Volume"));
+        }
+        gtk_widget_show(img);
+        gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(mi), img);
+        gtk_widget_show(mi);
+        gtk_menu_shell_append(GTK_MENU_SHELL(menu), mi);
         g_signal_connect(G_OBJECT(mi), "activate",
                          G_CALLBACK(xfdesktop_volume_icon_menu_toggle_mount),
                          icon);
     }
-    
-    mi = gtk_image_menu_item_new_with_mnemonic(_("_Unmount Volume"));
-    gtk_widget_show(mi);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu), mi);
-    if(!thunar_vfs_volume_is_mounted(volume))
-        gtk_widget_set_sensitive(mi, FALSE);
-    else {
-        g_signal_connect(G_OBJECT(mi), "activate",
-                         G_CALLBACK(xfdesktop_volume_icon_menu_toggle_mount),
-                         icon);
-    }
-    
-    if(thunar_vfs_volume_is_disc(volume)
-       && thunar_vfs_volume_is_ejectable(volume))
-    {
+
+    if(ejectable) {
+        img = gtk_image_new_from_icon_name("media-eject", GTK_ICON_SIZE_MENU);
+        gtk_widget_show(img);
         mi = gtk_image_menu_item_new_with_mnemonic(_("E_ject Volume"));
+        gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(mi), img);
         gtk_widget_show(mi);
         gtk_menu_shell_append(GTK_MENU_SHELL(menu), mi);
         g_signal_connect(G_OBJECT(mi), "activate",
                          G_CALLBACK(xfdesktop_volume_icon_menu_eject),
                          icon);
     }
-    
+
     mi = gtk_separator_menu_item_new();
     gtk_widget_show(mi);
     gtk_menu_shell_append(GTK_MENU_SHELL(menu), mi);
-    
+
     img = gtk_image_new_from_stock(GTK_STOCK_PROPERTIES, GTK_ICON_SIZE_MENU);
     gtk_widget_show(img);
     mi = gtk_image_menu_item_new_with_mnemonic(_("_Properties..."));
